@@ -6,10 +6,7 @@ test_that("skim returns expected response for numeric vectors", {
   expect_n_columns(input, 12)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "numeric.mean", "numeric.sd", "numeric.p0", "numeric.p25",
@@ -39,7 +36,6 @@ test_that("skim returns expected response for numeric vectors", {
   expect_equal(input$numeric.p50, 19.2, tolerance = 0.1)
   expect_equal(input$numeric.p75, 22.8, tolerance = 0.1)
   expect_equal(input$numeric.p100, 33.9, tolerance = 0.1)
-  skip_on_os("windows")
   skip_if_not(l10n_info()$`UTF-8`)
   expect_identical(input$numeric.hist, "▃▇▅▁▂")
 })
@@ -69,7 +65,6 @@ test_that("skim handles numeric vectors with NAs and extreme numbers", {
   expect_equal(input$numeric.p50, 0)
   expect_equal(input$numeric.p75, 4.5e+15, tolerance = 1e14)
   expect_equal(input$numeric.p100, 9.01e+15, tolerance = 1e14)
-  skip_on_os("windows")
   skip_if_not(l10n_info()$`UTF-8`)
   expect_identical(input$numeric.hist, "▇▁▁▁▇")
 })
@@ -97,7 +92,6 @@ test_that("numeric skim is calculated correctly when x is all NAs.", {
   expect_NA(input$numeric.p50)
   expect_NA(input$numeric.p75)
   expect_NA(input$numeric.p100)
-  skip_on_os("windows")
   skip_if_not(l10n_info()$`UTF-8`)
   expect_identical(input$numeric.hist, " ")
 })
@@ -125,7 +119,6 @@ test_that("numeric skim is calculated correctly when x is all zeores or NAs.", {
   expect_equal(input$numeric.p50, 0)
   expect_equal(input$numeric.p75, 0)
   expect_equal(input$numeric.p100, 0)
-  skip_on_os("windows")
   skip_if_not(l10n_info()$`UTF-8`)
   expect_identical(input$numeric.hist, "▁▁▇▁▁")
 })
@@ -146,7 +139,6 @@ test_that("Skimming with non-finite values works", {
   expect_equal(input$numeric.p50, 0)
   expect_equal(input$numeric.p75, Inf)
   expect_equal(input$numeric.p100, Inf)
-  skip_on_os("windows")
   skip_if_not(l10n_info()$`UTF-8`)
   expect_identical(input$numeric.hist, "▁▁▇▁▁")
 })
@@ -201,10 +193,7 @@ test_that("skim returns expected response for character vectors", {
   expect_n_columns(input, 9)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "character.min", "character.max", "character.empty",
@@ -242,10 +231,7 @@ test_that("skim returns expected response for logical vectors", {
   expect_n_columns(input, 6)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "logical.mean", "logical.count"
@@ -292,10 +278,7 @@ test_that("skim returns expected response for complex vectors", {
   expect_n_columns(input, 5)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(
     input,
     c(
@@ -322,7 +305,7 @@ test_that("skim returns expected response for complex vectors", {
 })
 
 test_that("skim returns expected response for Date vectors", {
-  dat <- seq(as.Date("2011-07-01"), by = 1, len = 9)
+  dat <- seq(as.Date("2011-07-01"), by = 1, length.out = 9)
   x <- tibble::tibble(dat)
   input <- skim(x)
 
@@ -331,10 +314,7 @@ test_that("skim returns expected response for Date vectors", {
   expect_n_columns(input, 8)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "Date.min", "Date.max", "Date.median", "Date.n_unique"
@@ -369,10 +349,7 @@ test_that("skim returns expected response for ts vectors", {
   expect_n_columns(input, 14)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "ts.start", "ts.end", "ts.frequency", "ts.deltat", "ts.mean", "ts.sd",
@@ -402,7 +379,7 @@ test_that("skim returns expected response for ts vectors", {
   expect_equal(input$ts.frequency, 4)
   expect_equal(input$ts.deltat, 0.25)
   expect_equal(input$ts.mean, 9.31, tolerance = 0.001)
-  expect_equal(input$ts.sd, 0.316, tolerance = 0.001)
+  expect_equal(input$ts.sd, 0.316, tolerance = 0.01)
   expect_equal(input$ts.min, 8.79, tolerance = 0.001)
   expect_equal(input$ts.max, 9.79, tolerance = 0.001)
   expect_equal(input$ts.median, 9.31, tolerance = 0.001)
@@ -410,7 +387,7 @@ test_that("skim returns expected response for ts vectors", {
 })
 
 test_that("skim returns expected response for POSIXct vectors", {
-  dat <- seq(as.POSIXct("2011-07-01 00:00:00", tz = "UTC"), by = 1, len = 10)
+  dat <- seq(as.POSIXct("2011-07-01 00:00:00", tz = "UTC"), by = 1, length.out = 10)
   dat[2] <- NA
   posix <- tibble::tibble(dat)
   input <- skim(posix)
@@ -420,10 +397,7 @@ test_that("skim returns expected response for POSIXct vectors", {
   expect_n_columns(input, 8)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "POSIXct.min", "POSIXct.max", "POSIXct.median",
@@ -477,10 +451,7 @@ test_that("skim returns expected response for list (not AsIs) vectors", {
   expect_n_columns(input, 7)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "list.n_unique", "list.min_length", "list.max_length"
@@ -516,10 +487,7 @@ test_that("skim returns expected response for list with all NA's", {
   expect_n_columns(input, 7)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "list.n_unique", "list.min_length", "list.max_length"
@@ -555,10 +523,7 @@ test_that("skim returns expected response for asis vectors", {
   expect_n_columns(input, 7)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "AsIs.n_unique", "AsIs.min_length", "AsIs.max_length"
@@ -596,10 +561,7 @@ test_that("skim returns expected response for difftime vectors", {
   expect_n_columns(input, 8)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "difftime.min", "difftime.max", "difftime.median",
@@ -637,10 +599,7 @@ test_that("skim returns expected response for lubridate Timespan vectors", {
   expect_n_columns(input, 8)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "Timespan.min", "Timespan.max", "Timespan.median",
@@ -678,10 +637,7 @@ test_that("skim handles objects containing haven_labelled vectors: double", {
   expect_n_columns(input, 12)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "numeric.mean", "numeric.sd", "numeric.p0", "numeric.p25",
@@ -727,10 +683,7 @@ test_that("skim handles objects containing haven_labelled vectors: character", {
   expect_n_columns(input, 9)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "character.min", "character.max", "character.empty",
@@ -760,7 +713,7 @@ test_that("skim handles objects containing haven_labelled vectors: character", {
 })
 
 test_that("skim handles objects with multiple classes", {
-  dat <- seq(as.Date("2011-07-01"), by = 1, len = 10)
+  dat <- seq(as.Date("2011-07-01"), by = 1, length.out = 10)
   dat[2] <- NA
   class(dat) <- c("strange_type", "Date")
   x <- tibble::tibble(dat)
@@ -771,10 +724,7 @@ test_that("skim handles objects with multiple classes", {
   expect_n_columns(input, 8)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "Date.min", "Date.max", "Date.median", "Date.n_unique"
@@ -792,10 +742,7 @@ test_that("skim treats unknown classes as character", {
   expect_warning(input <- skim(x))
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "character.min", "character.max", "character.empty",
@@ -824,10 +771,7 @@ test_that("skim handles objects with two unknown classes", {
   expect_warning(input <- skim(x))
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "character.min", "character.max", "character.empty",
@@ -857,10 +801,7 @@ test_that("Skimming a complete data frame works as expected", {
   expect_n_columns(input, 15)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "n_missing", "complete_rate",
     "factor.ordered", "factor.n_unique", "factor.top_counts",
@@ -885,17 +826,14 @@ test_that("Skimming a complete data frame works as expected", {
 
 test_that("successfully skim mixed data types with common skimmers", {
   df <- data.frame(
-    Date = seq(as.Date("2011-07-01"), by = 1, len = 10),
+    Date = seq(as.Date("2011-07-01"), by = 1, length.out = 10),
     POSIXct = as.POSIXct("2011-07-01 00:00:00", tz = "UTC")
   )
   input <- skim(df)
   expect_n_rows(input, 2)
   expect_n_columns(input, 12)
 
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(
     input,
     c(
@@ -957,10 +895,7 @@ test_that("Skimming a grouped df with selections works as expected", {
   expect_n_columns(input, 14)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "cyl", "gear", "n_missing",
     "complete_rate", "numeric.mean", "numeric.sd", "numeric.p0",
@@ -988,10 +923,7 @@ test_that("Skimming a grouped df works when selecting exactly one variable", {
   expect_n_columns(input, 14)
 
   # classes
-  expect_s3_class(input, "skim_df")
-  expect_s3_class(input, "tbl_df")
-  expect_s3_class(input, "tbl")
-  expect_s3_class(input, "data.frame")
+  expect_s3_class(input, c("skim_df", "tbl_df", "tbl", "data.frame"))
   expect_named(input, c(
     "skim_type", "skim_variable", "cyl", "gear", "n_missing",
     "complete_rate", "numeric.mean", "numeric.sd", "numeric.p0",
